"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ContentLabelTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ContentLabelType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContentLabelType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ContentLabelTypeEnum.ContentLabelType.V(0)
        UNKNOWN = ContentLabelTypeEnum.ContentLabelType.V(1)
        SEXUALLY_SUGGESTIVE = ContentLabelTypeEnum.ContentLabelType.V(2)
        BELOW_THE_FOLD = ContentLabelTypeEnum.ContentLabelType.V(3)
        PARKED_DOMAIN = ContentLabelTypeEnum.ContentLabelType.V(4)
        JUVENILE = ContentLabelTypeEnum.ContentLabelType.V(6)
        PROFANITY = ContentLabelTypeEnum.ContentLabelType.V(7)
        TRAGEDY = ContentLabelTypeEnum.ContentLabelType.V(8)
        VIDEO = ContentLabelTypeEnum.ContentLabelType.V(9)
        VIDEO_RATING_DV_G = ContentLabelTypeEnum.ContentLabelType.V(10)
        VIDEO_RATING_DV_PG = ContentLabelTypeEnum.ContentLabelType.V(11)
        VIDEO_RATING_DV_T = ContentLabelTypeEnum.ContentLabelType.V(12)
        VIDEO_RATING_DV_MA = ContentLabelTypeEnum.ContentLabelType.V(13)
        VIDEO_NOT_YET_RATED = ContentLabelTypeEnum.ContentLabelType.V(14)
        EMBEDDED_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(15)
        LIVE_STREAMING_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(16)
        SOCIAL_ISSUES = ContentLabelTypeEnum.ContentLabelType.V(17)
    class ContentLabelType(metaclass=_ContentLabelType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ContentLabelTypeEnum.ContentLabelType.V(0)
    UNKNOWN = ContentLabelTypeEnum.ContentLabelType.V(1)
    SEXUALLY_SUGGESTIVE = ContentLabelTypeEnum.ContentLabelType.V(2)
    BELOW_THE_FOLD = ContentLabelTypeEnum.ContentLabelType.V(3)
    PARKED_DOMAIN = ContentLabelTypeEnum.ContentLabelType.V(4)
    JUVENILE = ContentLabelTypeEnum.ContentLabelType.V(6)
    PROFANITY = ContentLabelTypeEnum.ContentLabelType.V(7)
    TRAGEDY = ContentLabelTypeEnum.ContentLabelType.V(8)
    VIDEO = ContentLabelTypeEnum.ContentLabelType.V(9)
    VIDEO_RATING_DV_G = ContentLabelTypeEnum.ContentLabelType.V(10)
    VIDEO_RATING_DV_PG = ContentLabelTypeEnum.ContentLabelType.V(11)
    VIDEO_RATING_DV_T = ContentLabelTypeEnum.ContentLabelType.V(12)
    VIDEO_RATING_DV_MA = ContentLabelTypeEnum.ContentLabelType.V(13)
    VIDEO_NOT_YET_RATED = ContentLabelTypeEnum.ContentLabelType.V(14)
    EMBEDDED_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(15)
    LIVE_STREAMING_VIDEO = ContentLabelTypeEnum.ContentLabelType.V(16)
    SOCIAL_ISSUES = ContentLabelTypeEnum.ContentLabelType.V(17)
    def __init__(
        self,
    ) -> None: ...

global___ContentLabelTypeEnum = ContentLabelTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaBundleErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaBundleError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaBundleError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaBundleErrorEnum.MediaBundleError.V(0)
        UNKNOWN = MediaBundleErrorEnum.MediaBundleError.V(1)
        BAD_REQUEST = MediaBundleErrorEnum.MediaBundleError.V(3)
        DOUBLECLICK_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(4)
        EXTERNAL_URL_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(5)
        FILE_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(6)
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
            MediaBundleErrorEnum.MediaBundleError.V(7)
        )
        INVALID_INPUT = MediaBundleErrorEnum.MediaBundleError.V(8)
        INVALID_MEDIA_BUNDLE = MediaBundleErrorEnum.MediaBundleError.V(9)
        INVALID_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(10)
        INVALID_MIME_TYPE = MediaBundleErrorEnum.MediaBundleError.V(11)
        INVALID_PATH = MediaBundleErrorEnum.MediaBundleError.V(12)
        INVALID_URL_REFERENCE = MediaBundleErrorEnum.MediaBundleError.V(13)
        MEDIA_DATA_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(14)
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(15)
        SERVER_ERROR = MediaBundleErrorEnum.MediaBundleError.V(16)
        STORAGE_ERROR = MediaBundleErrorEnum.MediaBundleError.V(17)
        SWIFFY_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(18)
        TOO_MANY_FILES = MediaBundleErrorEnum.MediaBundleError.V(19)
        UNEXPECTED_SIZE = MediaBundleErrorEnum.MediaBundleError.V(20)
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
            MediaBundleErrorEnum.MediaBundleError.V(21)
        )
        UNSUPPORTED_HTML5_FEATURE = MediaBundleErrorEnum.MediaBundleError.V(22)
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaBundleErrorEnum.MediaBundleError.V(
            23
        )
        CUSTOM_EXIT_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(24)
    class MediaBundleError(metaclass=_MediaBundleError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaBundleErrorEnum.MediaBundleError.V(0)
    UNKNOWN = MediaBundleErrorEnum.MediaBundleError.V(1)
    BAD_REQUEST = MediaBundleErrorEnum.MediaBundleError.V(3)
    DOUBLECLICK_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(4)
    EXTERNAL_URL_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(5)
    FILE_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(6)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = (
        MediaBundleErrorEnum.MediaBundleError.V(7)
    )
    INVALID_INPUT = MediaBundleErrorEnum.MediaBundleError.V(8)
    INVALID_MEDIA_BUNDLE = MediaBundleErrorEnum.MediaBundleError.V(9)
    INVALID_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(10)
    INVALID_MIME_TYPE = MediaBundleErrorEnum.MediaBundleError.V(11)
    INVALID_PATH = MediaBundleErrorEnum.MediaBundleError.V(12)
    INVALID_URL_REFERENCE = MediaBundleErrorEnum.MediaBundleError.V(13)
    MEDIA_DATA_TOO_LARGE = MediaBundleErrorEnum.MediaBundleError.V(14)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = MediaBundleErrorEnum.MediaBundleError.V(15)
    SERVER_ERROR = MediaBundleErrorEnum.MediaBundleError.V(16)
    STORAGE_ERROR = MediaBundleErrorEnum.MediaBundleError.V(17)
    SWIFFY_BUNDLE_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(18)
    TOO_MANY_FILES = MediaBundleErrorEnum.MediaBundleError.V(19)
    UNEXPECTED_SIZE = MediaBundleErrorEnum.MediaBundleError.V(20)
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = (
        MediaBundleErrorEnum.MediaBundleError.V(21)
    )
    UNSUPPORTED_HTML5_FEATURE = MediaBundleErrorEnum.MediaBundleError.V(22)
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = MediaBundleErrorEnum.MediaBundleError.V(23)
    CUSTOM_EXIT_NOT_ALLOWED = MediaBundleErrorEnum.MediaBundleError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___MediaBundleErrorEnum = MediaBundleErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AppPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AppPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AppPlaceholderFieldEnum.AppPlaceholderField.V(0)
        UNKNOWN = AppPlaceholderFieldEnum.AppPlaceholderField.V(1)
        STORE = AppPlaceholderFieldEnum.AppPlaceholderField.V(2)
        ID = AppPlaceholderFieldEnum.AppPlaceholderField.V(3)
        LINK_TEXT = AppPlaceholderFieldEnum.AppPlaceholderField.V(4)
        URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(5)
        FINAL_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(6)
        FINAL_MOBILE_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(7)
        TRACKING_URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(8)
        FINAL_URL_SUFFIX = AppPlaceholderFieldEnum.AppPlaceholderField.V(9)
    class AppPlaceholderField(metaclass=_AppPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AppPlaceholderFieldEnum.AppPlaceholderField.V(0)
    UNKNOWN = AppPlaceholderFieldEnum.AppPlaceholderField.V(1)
    STORE = AppPlaceholderFieldEnum.AppPlaceholderField.V(2)
    ID = AppPlaceholderFieldEnum.AppPlaceholderField.V(3)
    LINK_TEXT = AppPlaceholderFieldEnum.AppPlaceholderField.V(4)
    URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(5)
    FINAL_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(6)
    FINAL_MOBILE_URLS = AppPlaceholderFieldEnum.AppPlaceholderField.V(7)
    TRACKING_URL = AppPlaceholderFieldEnum.AppPlaceholderField.V(8)
    FINAL_URL_SUFFIX = AppPlaceholderFieldEnum.AppPlaceholderField.V(9)
    def __init__(
        self,
    ) -> None: ...

global___AppPlaceholderFieldEnum = AppPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Money(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        amount_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "amount_micros", b"amount_micros", "currency_code", b"currency_code"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "amount_micros", b"amount_micros", "currency_code", b"currency_code"
        ],
    ) -> None: ...

global___Money = Money



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyValidationParameterErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyValidationParameterError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyValidationParameterError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(0)
        )
        UNKNOWN = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(1)
        UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(2)
        )
        UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(3)
        )
        CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = (
            PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(4)
        )
    class PolicyValidationParameterError(metaclass=_PolicyValidationParameterError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(0)
    UNKNOWN = PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(1)
    UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(2)
    )
    UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(3)
    )
    CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS = (
        PolicyValidationParameterErrorEnum.PolicyValidationParameterError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___PolicyValidationParameterErrorEnum = PolicyValidationParameterErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2
import google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TagSnippet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    PAGE_FORMAT_FIELD_NUMBER: builtins.int
    GLOBAL_SITE_TAG_FIELD_NUMBER: builtins.int
    EVENT_SNIPPET_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2.TrackingCodeTypeEnum.TrackingCodeType.V = (
        ...
    )
    page_format: google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2.TrackingCodePageFormatEnum.TrackingCodePageFormat.V = (
        ...
    )
    global_site_tag: typing.Text = ...
    event_snippet: typing.Text = ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.tracking_code_type_pb2.TrackingCodeTypeEnum.TrackingCodeType.V = ...,
        page_format: google.ads.google_ads.v5.proto.enums.tracking_code_page_format_pb2.TrackingCodePageFormatEnum.TrackingCodePageFormat.V = ...,
        global_site_tag: typing.Text = ...,
        event_snippet: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_event_snippet",
            b"_event_snippet",
            "_global_site_tag",
            b"_global_site_tag",
            "event_snippet",
            b"event_snippet",
            "global_site_tag",
            b"global_site_tag",
            "page_format",
            b"page_format",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_event_snippet", b"_event_snippet"],
    ) -> typing_extensions.Literal["event_snippet"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_global_site_tag", b"_global_site_tag"],
    ) -> typing_extensions.Literal["global_site_tag"]: ...

global___TagSnippet = TagSnippet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelPriceBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelPriceBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HotelPriceBucket.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelPriceBucketEnum.HotelPriceBucket.V(0)
        UNKNOWN = HotelPriceBucketEnum.HotelPriceBucket.V(1)
        LOWEST_UNIQUE = HotelPriceBucketEnum.HotelPriceBucket.V(2)
        LOWEST_TIED = HotelPriceBucketEnum.HotelPriceBucket.V(3)
        NOT_LOWEST = HotelPriceBucketEnum.HotelPriceBucket.V(4)
        ONLY_PARTNER_SHOWN = HotelPriceBucketEnum.HotelPriceBucket.V(5)
    class HotelPriceBucket(metaclass=_HotelPriceBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelPriceBucketEnum.HotelPriceBucket.V(0)
    UNKNOWN = HotelPriceBucketEnum.HotelPriceBucket.V(1)
    LOWEST_UNIQUE = HotelPriceBucketEnum.HotelPriceBucket.V(2)
    LOWEST_TIED = HotelPriceBucketEnum.HotelPriceBucket.V(3)
    NOT_LOWEST = HotelPriceBucketEnum.HotelPriceBucket.V(4)
    ONLY_PARTNER_SHOWN = HotelPriceBucketEnum.HotelPriceBucket.V(5)
    def __init__(
        self,
    ) -> None: ...

global___HotelPriceBucketEnum = HotelPriceBucketEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserListError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListErrorEnum.UserListError.V(0)
        UNKNOWN = UserListErrorEnum.UserListError.V(1)
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = (
            UserListErrorEnum.UserListError.V(2)
        )
        CONCRETE_TYPE_REQUIRED = UserListErrorEnum.UserListError.V(3)
        CONVERSION_TYPE_ID_REQUIRED = UserListErrorEnum.UserListError.V(4)
        DUPLICATE_CONVERSION_TYPES = UserListErrorEnum.UserListError.V(5)
        INVALID_CONVERSION_TYPE = UserListErrorEnum.UserListError.V(6)
        INVALID_DESCRIPTION = UserListErrorEnum.UserListError.V(7)
        INVALID_NAME = UserListErrorEnum.UserListError.V(8)
        INVALID_TYPE = UserListErrorEnum.UserListError.V(9)
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = (
            UserListErrorEnum.UserListError.V(10)
        )
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND = UserListErrorEnum.UserListError.V(11)
        NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(12)
        NEW_CONVERSION_TYPE_NAME_REQUIRED = UserListErrorEnum.UserListError.V(13)
        CONVERSION_TYPE_NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(14)
        OWNERSHIP_REQUIRED_FOR_SET = UserListErrorEnum.UserListError.V(15)
        USER_LIST_MUTATE_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(16)
        INVALID_RULE = UserListErrorEnum.UserListError.V(17)
        INVALID_DATE_RANGE = UserListErrorEnum.UserListError.V(27)
        CAN_NOT_MUTATE_SENSITIVE_USERLIST = UserListErrorEnum.UserListError.V(28)
        MAX_NUM_RULEBASED_USERLISTS = UserListErrorEnum.UserListError.V(29)
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT = UserListErrorEnum.UserListError.V(30)
        APP_ID_NOT_SET = UserListErrorEnum.UserListError.V(31)
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = UserListErrorEnum.UserListError.V(
            32
        )
        ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = (
            UserListErrorEnum.UserListError.V(33)
        )
        RULE_TYPE_IS_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(34)
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = (
            UserListErrorEnum.UserListError.V(35)
        )
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = (
            UserListErrorEnum.UserListError.V(36)
        )
    class UserListError(metaclass=_UserListError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListErrorEnum.UserListError.V(0)
    UNKNOWN = UserListErrorEnum.UserListError.V(1)
    EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED = (
        UserListErrorEnum.UserListError.V(2)
    )
    CONCRETE_TYPE_REQUIRED = UserListErrorEnum.UserListError.V(3)
    CONVERSION_TYPE_ID_REQUIRED = UserListErrorEnum.UserListError.V(4)
    DUPLICATE_CONVERSION_TYPES = UserListErrorEnum.UserListError.V(5)
    INVALID_CONVERSION_TYPE = UserListErrorEnum.UserListError.V(6)
    INVALID_DESCRIPTION = UserListErrorEnum.UserListError.V(7)
    INVALID_NAME = UserListErrorEnum.UserListError.V(8)
    INVALID_TYPE = UserListErrorEnum.UserListError.V(9)
    CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND = (
        UserListErrorEnum.UserListError.V(10)
    )
    INVALID_USER_LIST_LOGICAL_RULE_OPERAND = UserListErrorEnum.UserListError.V(11)
    NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(12)
    NEW_CONVERSION_TYPE_NAME_REQUIRED = UserListErrorEnum.UserListError.V(13)
    CONVERSION_TYPE_NAME_ALREADY_USED = UserListErrorEnum.UserListError.V(14)
    OWNERSHIP_REQUIRED_FOR_SET = UserListErrorEnum.UserListError.V(15)
    USER_LIST_MUTATE_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(16)
    INVALID_RULE = UserListErrorEnum.UserListError.V(17)
    INVALID_DATE_RANGE = UserListErrorEnum.UserListError.V(27)
    CAN_NOT_MUTATE_SENSITIVE_USERLIST = UserListErrorEnum.UserListError.V(28)
    MAX_NUM_RULEBASED_USERLISTS = UserListErrorEnum.UserListError.V(29)
    CANNOT_MODIFY_BILLABLE_RECORD_COUNT = UserListErrorEnum.UserListError.V(30)
    APP_ID_NOT_SET = UserListErrorEnum.UserListError.V(31)
    USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST = UserListErrorEnum.UserListError.V(32)
    ADVERTISER_NOT_WHITELISTED_FOR_USING_UPLOADED_DATA = (
        UserListErrorEnum.UserListError.V(33)
    )
    RULE_TYPE_IS_NOT_SUPPORTED = UserListErrorEnum.UserListError.V(34)
    CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND = (
        UserListErrorEnum.UserListError.V(35)
    )
    CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS = (
        UserListErrorEnum.UserListError.V(36)
    )
    def __init__(
        self,
    ) -> None: ...

global___UserListErrorEnum = UserListErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserAddressInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASHED_FIRST_NAME_FIELD_NUMBER: builtins.int
    HASHED_LAST_NAME_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    @property
    def hashed_first_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def hashed_last_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def city(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def state(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def postal_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        hashed_first_name: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        hashed_last_name: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        city: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        state: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        postal_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> None: ...

global___OfflineUserAddressInfo = OfflineUserAddressInfo

class UserIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASHED_EMAIL_FIELD_NUMBER: builtins.int
    HASHED_PHONE_NUMBER_FIELD_NUMBER: builtins.int
    MOBILE_ID_FIELD_NUMBER: builtins.int
    THIRD_PARTY_USER_ID_FIELD_NUMBER: builtins.int
    ADDRESS_INFO_FIELD_NUMBER: builtins.int
    @property
    def hashed_email(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def hashed_phone_number(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def mobile_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def third_party_user_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def address_info(self) -> global___OfflineUserAddressInfo: ...
    def __init__(
        self,
        *,
        hashed_email: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        hashed_phone_number: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        mobile_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        third_party_user_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        address_info: typing.Optional[global___OfflineUserAddressInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["identifier", b"identifier"]
    ) -> typing_extensions.Literal[
        "hashed_email",
        "hashed_phone_number",
        "mobile_id",
        "third_party_user_id",
        "address_info",
    ]: ...

global___UserIdentifier = UserIdentifier

class TransactionAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TRANSACTION_DATE_TIME_FIELD_NUMBER: builtins.int
    TRANSACTION_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    STORE_ATTRIBUTE_FIELD_NUMBER: builtins.int
    CUSTOM_VALUE_FIELD_NUMBER: builtins.int
    @property
    def transaction_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def transaction_amount_micros(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def conversion_action(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def order_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def store_attribute(self) -> global___StoreAttribute: ...
    @property
    def custom_value(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        transaction_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        transaction_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        conversion_action: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        order_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        store_attribute: typing.Optional[global___StoreAttribute] = ...,
        custom_value: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> None: ...

global___TransactionAttribute = TransactionAttribute

class StoreAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STORE_CODE_FIELD_NUMBER: builtins.int
    @property
    def store_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        store_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["store_code", b"store_code"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["store_code", b"store_code"]
    ) -> None: ...

global___StoreAttribute = StoreAttribute

class UserData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_IDENTIFIERS_FIELD_NUMBER: builtins.int
    TRANSACTION_ATTRIBUTE_FIELD_NUMBER: builtins.int
    @property
    def user_identifiers(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserIdentifier
    ]: ...
    @property
    def transaction_attribute(self) -> global___TransactionAttribute: ...
    def __init__(
        self,
        *,
        user_identifiers: typing.Optional[
            typing.Iterable[global___UserIdentifier]
        ] = ...,
        transaction_attribute: typing.Optional[global___TransactionAttribute] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "transaction_attribute", b"transaction_attribute"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_identifiers",
            b"user_identifiers",
        ],
    ) -> None: ...

global___UserData = UserData

class CustomerMatchUserListMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_LIST_FIELD_NUMBER: builtins.int
    @property
    def user_list(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        user_list: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["user_list", b"user_list"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["user_list", b"user_list"]
    ) -> None: ...

global___CustomerMatchUserListMetadata = CustomerMatchUserListMetadata

class StoreSalesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOYALTY_FRACTION_FIELD_NUMBER: builtins.int
    TRANSACTION_UPLOAD_FRACTION_FIELD_NUMBER: builtins.int
    CUSTOM_KEY_FIELD_NUMBER: builtins.int
    THIRD_PARTY_METADATA_FIELD_NUMBER: builtins.int
    @property
    def loyalty_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def transaction_upload_fraction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def custom_key(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def third_party_metadata(self) -> global___StoreSalesThirdPartyMetadata: ...
    def __init__(
        self,
        *,
        loyalty_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        transaction_upload_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        custom_key: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        third_party_metadata: typing.Optional[
            global___StoreSalesThirdPartyMetadata
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> None: ...

global___StoreSalesMetadata = StoreSalesMetadata

class StoreSalesThirdPartyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADVERTISER_UPLOAD_DATE_TIME_FIELD_NUMBER: builtins.int
    VALID_TRANSACTION_FRACTION_FIELD_NUMBER: builtins.int
    PARTNER_MATCH_FRACTION_FIELD_NUMBER: builtins.int
    PARTNER_UPLOAD_FRACTION_FIELD_NUMBER: builtins.int
    BRIDGE_MAP_VERSION_ID_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    @property
    def advertiser_upload_date_time(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def valid_transaction_fraction(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def partner_match_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def partner_upload_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def bridge_map_version_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def partner_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        advertiser_upload_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        valid_transaction_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        partner_match_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        partner_upload_fraction: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        bridge_map_version_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        partner_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> None: ...

global___StoreSalesThirdPartyMetadata = StoreSalesThirdPartyMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NegativeGeoTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _NegativeGeoTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NegativeGeoTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(0)
        UNKNOWN = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(1)
        PRESENCE_OR_INTEREST = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(4)
        PRESENCE = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(5)
    class NegativeGeoTargetType(metaclass=_NegativeGeoTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(0)
    UNKNOWN = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(1)
    PRESENCE_OR_INTEREST = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(4)
    PRESENCE = NegativeGeoTargetTypeEnum.NegativeGeoTargetType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___NegativeGeoTargetTypeEnum = NegativeGeoTargetTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.criteria_pb2
import google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2
import google.ads.google_ads.v4.proto.enums.reach_plan_ad_length_pb2
import google.ads.google_ads.v4.proto.enums.reach_plan_age_range_pb2
import google.ads.google_ads.v4.proto.enums.reach_plan_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ListPlannableLocationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ListPlannableLocationsRequest = ListPlannableLocationsRequest

class ListPlannableLocationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_LOCATIONS_FIELD_NUMBER: builtins.int
    @property
    def plannable_locations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PlannableLocation
    ]: ...
    def __init__(
        self,
        *,
        plannable_locations: typing.Optional[
            typing.Iterable[global___PlannableLocation]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_locations", b"plannable_locations"
        ],
    ) -> None: ...

global___ListPlannableLocationsResponse = ListPlannableLocationsResponse

class PlannableLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_COUNTRY_ID_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def parent_country_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        parent_country_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "id", b"id", "name", b"name", "parent_country_id", b"parent_country_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id", b"id", "name", b"name", "parent_country_id", b"parent_country_id"
        ],
    ) -> None: ...

global___PlannableLocation = PlannableLocation

class ListPlannableProductsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_LOCATION_ID_FIELD_NUMBER: builtins.int
    @property
    def plannable_location_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        plannable_location_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> None: ...

global___ListPlannableProductsRequest = ListPlannableProductsRequest

class ListPlannableProductsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_METADATA_FIELD_NUMBER: builtins.int
    @property
    def product_metadata(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductMetadata
    ]: ...
    def __init__(
        self,
        *,
        product_metadata: typing.Optional[
            typing.Iterable[global___ProductMetadata]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["product_metadata", b"product_metadata"],
    ) -> None: ...

global___ListPlannableProductsResponse = ListPlannableProductsResponse

class ProductMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_PRODUCT_CODE_FIELD_NUMBER: builtins.int
    PLANNABLE_TARGETING_FIELD_NUMBER: builtins.int
    @property
    def plannable_product_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def plannable_targeting(self) -> global___PlannableTargeting: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        plannable_targeting: typing.Optional[global___PlannableTargeting] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_product_code",
            b"plannable_product_code",
            "plannable_targeting",
            b"plannable_targeting",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_product_code",
            b"plannable_product_code",
            "plannable_targeting",
            b"plannable_targeting",
        ],
    ) -> None: ...

global___ProductMetadata = ProductMetadata

class PlannableTargeting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AGE_RANGES_FIELD_NUMBER: builtins.int
    GENDERS_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    NETWORKS_FIELD_NUMBER: builtins.int
    age_ranges: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.reach_plan_age_range_pb2.ReachPlanAgeRangeEnum.ReachPlanAgeRange.V
    ] = ...
    networks: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.reach_plan_network_pb2.ReachPlanNetworkEnum.ReachPlanNetwork.V
    ] = ...
    @property
    def genders(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criteria_pb2.GenderInfo
    ]: ...
    @property
    def devices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criteria_pb2.DeviceInfo
    ]: ...
    def __init__(
        self,
        *,
        age_ranges: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.reach_plan_age_range_pb2.ReachPlanAgeRangeEnum.ReachPlanAgeRange.V
            ]
        ] = ...,
        genders: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criteria_pb2.GenderInfo
            ]
        ] = ...,
        devices: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criteria_pb2.DeviceInfo
            ]
        ] = ...,
        networks: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.reach_plan_network_pb2.ReachPlanNetworkEnum.ReachPlanNetwork.V
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "age_ranges",
            b"age_ranges",
            "devices",
            b"devices",
            "genders",
            b"genders",
            "networks",
            b"networks",
        ],
    ) -> None: ...

global___PlannableTargeting = PlannableTargeting

class GenerateProductMixIdeasRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    PLANNABLE_LOCATION_ID_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    BUDGET_MICROS_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def plannable_location_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def budget_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def preferences(self) -> global___Preferences: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        plannable_location_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        budget_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        preferences: typing.Optional[global___Preferences] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "currency_code",
            b"currency_code",
            "plannable_location_id",
            b"plannable_location_id",
            "preferences",
            b"preferences",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "currency_code",
            b"currency_code",
            "customer_id",
            b"customer_id",
            "plannable_location_id",
            b"plannable_location_id",
            "preferences",
            b"preferences",
        ],
    ) -> None: ...

global___GenerateProductMixIdeasRequest = GenerateProductMixIdeasRequest

class Preferences(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IS_SKIPPABLE_FIELD_NUMBER: builtins.int
    STARTS_WITH_SOUND_FIELD_NUMBER: builtins.int
    AD_LENGTH_FIELD_NUMBER: builtins.int
    TOP_CONTENT_ONLY_FIELD_NUMBER: builtins.int
    HAS_GUARANTEED_PRICE_FIELD_NUMBER: builtins.int
    ad_length: google.ads.google_ads.v4.proto.enums.reach_plan_ad_length_pb2.ReachPlanAdLengthEnum.ReachPlanAdLength.V = (
        ...
    )
    @property
    def is_skippable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def starts_with_sound(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def top_content_only(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_guaranteed_price(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        is_skippable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        starts_with_sound: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        ad_length: google.ads.google_ads.v4.proto.enums.reach_plan_ad_length_pb2.ReachPlanAdLengthEnum.ReachPlanAdLength.V = ...,
        top_content_only: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        has_guaranteed_price: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "has_guaranteed_price",
            b"has_guaranteed_price",
            "is_skippable",
            b"is_skippable",
            "starts_with_sound",
            b"starts_with_sound",
            "top_content_only",
            b"top_content_only",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_length",
            b"ad_length",
            "has_guaranteed_price",
            b"has_guaranteed_price",
            "is_skippable",
            b"is_skippable",
            "starts_with_sound",
            b"starts_with_sound",
            "top_content_only",
            b"top_content_only",
        ],
    ) -> None: ...

global___Preferences = Preferences

class GenerateProductMixIdeasResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_ALLOCATION_FIELD_NUMBER: builtins.int
    @property
    def product_allocation(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductAllocation
    ]: ...
    def __init__(
        self,
        *,
        product_allocation: typing.Optional[
            typing.Iterable[global___ProductAllocation]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "product_allocation", b"product_allocation"
        ],
    ) -> None: ...

global___GenerateProductMixIdeasResponse = GenerateProductMixIdeasResponse

class ProductAllocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_PRODUCT_CODE_FIELD_NUMBER: builtins.int
    BUDGET_MICROS_FIELD_NUMBER: builtins.int
    @property
    def plannable_product_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def budget_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        budget_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> None: ...

global___ProductAllocation = ProductAllocation

class GenerateReachForecastRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    CAMPAIGN_DURATION_FIELD_NUMBER: builtins.int
    COOKIE_FREQUENCY_CAP_FIELD_NUMBER: builtins.int
    COOKIE_FREQUENCY_CAP_SETTING_FIELD_NUMBER: builtins.int
    MIN_EFFECTIVE_FREQUENCY_FIELD_NUMBER: builtins.int
    TARGETING_FIELD_NUMBER: builtins.int
    PLANNED_PRODUCTS_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def campaign_duration(self) -> global___CampaignDuration: ...
    @property
    def cookie_frequency_cap(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    @property
    def cookie_frequency_cap_setting(self) -> global___FrequencyCap: ...
    @property
    def min_effective_frequency(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    @property
    def targeting(self) -> global___Targeting: ...
    @property
    def planned_products(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PlannedProduct
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        campaign_duration: typing.Optional[global___CampaignDuration] = ...,
        cookie_frequency_cap: typing.Optional[
            google.protobuf.wrappers_pb2.Int32Value
        ] = ...,
        cookie_frequency_cap_setting: typing.Optional[global___FrequencyCap] = ...,
        min_effective_frequency: typing.Optional[
            google.protobuf.wrappers_pb2.Int32Value
        ] = ...,
        targeting: typing.Optional[global___Targeting] = ...,
        planned_products: typing.Optional[
            typing.Iterable[global___PlannedProduct]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "campaign_duration",
            b"campaign_duration",
            "cookie_frequency_cap",
            b"cookie_frequency_cap",
            "cookie_frequency_cap_setting",
            b"cookie_frequency_cap_setting",
            "currency_code",
            b"currency_code",
            "min_effective_frequency",
            b"min_effective_frequency",
            "targeting",
            b"targeting",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "campaign_duration",
            b"campaign_duration",
            "cookie_frequency_cap",
            b"cookie_frequency_cap",
            "cookie_frequency_cap_setting",
            b"cookie_frequency_cap_setting",
            "currency_code",
            b"currency_code",
            "customer_id",
            b"customer_id",
            "min_effective_frequency",
            b"min_effective_frequency",
            "planned_products",
            b"planned_products",
            "targeting",
            b"targeting",
        ],
    ) -> None: ...

global___GenerateReachForecastRequest = GenerateReachForecastRequest

class FrequencyCap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TIME_UNIT_FIELD_NUMBER: builtins.int
    time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = (
        ...
    )
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
        time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["impressions", b"impressions"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "impressions", b"impressions", "time_unit", b"time_unit"
        ],
    ) -> None: ...

global___FrequencyCap = FrequencyCap

class Targeting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_LOCATION_ID_FIELD_NUMBER: builtins.int
    AGE_RANGE_FIELD_NUMBER: builtins.int
    GENDERS_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    age_range: google.ads.google_ads.v4.proto.enums.reach_plan_age_range_pb2.ReachPlanAgeRangeEnum.ReachPlanAgeRange.V = (
        ...
    )
    network: google.ads.google_ads.v4.proto.enums.reach_plan_network_pb2.ReachPlanNetworkEnum.ReachPlanNetwork.V = (
        ...
    )
    @property
    def plannable_location_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def genders(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criteria_pb2.GenderInfo
    ]: ...
    @property
    def devices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criteria_pb2.DeviceInfo
    ]: ...
    def __init__(
        self,
        *,
        plannable_location_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        age_range: google.ads.google_ads.v4.proto.enums.reach_plan_age_range_pb2.ReachPlanAgeRangeEnum.ReachPlanAgeRange.V = ...,
        genders: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criteria_pb2.GenderInfo
            ]
        ] = ...,
        devices: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criteria_pb2.DeviceInfo
            ]
        ] = ...,
        network: google.ads.google_ads.v4.proto.enums.reach_plan_network_pb2.ReachPlanNetworkEnum.ReachPlanNetwork.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "plannable_location_id", b"plannable_location_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "age_range",
            b"age_range",
            "devices",
            b"devices",
            "genders",
            b"genders",
            "network",
            b"network",
            "plannable_location_id",
            b"plannable_location_id",
        ],
    ) -> None: ...

global___Targeting = Targeting

class CampaignDuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DURATION_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def duration_in_days(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        duration_in_days: typing.Optional[
            google.protobuf.wrappers_pb2.Int32Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["duration_in_days", b"duration_in_days"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["duration_in_days", b"duration_in_days"],
    ) -> None: ...

global___CampaignDuration = CampaignDuration

class PlannedProduct(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLANNABLE_PRODUCT_CODE_FIELD_NUMBER: builtins.int
    BUDGET_MICROS_FIELD_NUMBER: builtins.int
    @property
    def plannable_product_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def budget_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        plannable_product_code: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        budget_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "budget_micros",
            b"budget_micros",
            "plannable_product_code",
            b"plannable_product_code",
        ],
    ) -> None: ...

global___PlannedProduct = PlannedProduct

class GenerateReachForecastResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ON_TARGET_AUDIENCE_METRICS_FIELD_NUMBER: builtins.int
    REACH_CURVE_FIELD_NUMBER: builtins.int
    @property
    def on_target_audience_metrics(self) -> global___OnTargetAudienceMetrics: ...
    @property
    def reach_curve(self) -> global___ReachCurve: ...
    def __init__(
        self,
        *,
        on_target_audience_metrics: typing.Optional[
            global___OnTargetAudienceMetrics
        ] = ...,
        reach_curve: typing.Optional[global___ReachCurve] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "on_target_audience_metrics",
            b"on_target_audience_metrics",
            "reach_curve",
            b"reach_curve",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "on_target_audience_metrics",
            b"on_target_audience_metrics",
            "reach_curve",
            b"reach_curve",
        ],
    ) -> None: ...

global___GenerateReachForecastResponse = GenerateReachForecastResponse

class ReachCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REACH_FORECASTS_FIELD_NUMBER: builtins.int
    @property
    def reach_forecasts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ReachForecast
    ]: ...
    def __init__(
        self,
        *,
        reach_forecasts: typing.Optional[typing.Iterable[global___ReachForecast]] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["reach_forecasts", b"reach_forecasts"],
    ) -> None: ...

global___ReachCurve = ReachCurve

class ReachForecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COST_MICROS_FIELD_NUMBER: builtins.int
    FORECAST_FIELD_NUMBER: builtins.int
    FORECASTED_PRODUCT_ALLOCATIONS_FIELD_NUMBER: builtins.int
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def forecast(self) -> global___Forecast: ...
    @property
    def forecasted_product_allocations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductAllocation
    ]: ...
    def __init__(
        self,
        *,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        forecast: typing.Optional[global___Forecast] = ...,
        forecasted_product_allocations: typing.Optional[
            typing.Iterable[global___ProductAllocation]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros", b"cost_micros", "forecast", b"forecast"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros",
            b"cost_micros",
            "forecast",
            b"forecast",
            "forecasted_product_allocations",
            b"forecasted_product_allocations",
        ],
    ) -> None: ...

global___ReachForecast = ReachForecast

class Forecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ON_TARGET_REACH_FIELD_NUMBER: builtins.int
    TOTAL_REACH_FIELD_NUMBER: builtins.int
    ON_TARGET_IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOTAL_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def on_target_reach(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def total_reach(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def on_target_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def total_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        on_target_reach: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        total_reach: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        on_target_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        total_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "on_target_impressions",
            b"on_target_impressions",
            "on_target_reach",
            b"on_target_reach",
            "total_impressions",
            b"total_impressions",
            "total_reach",
            b"total_reach",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "on_target_impressions",
            b"on_target_impressions",
            "on_target_reach",
            b"on_target_reach",
            "total_impressions",
            b"total_impressions",
            "total_reach",
            b"total_reach",
        ],
    ) -> None: ...

global___Forecast = Forecast

class OnTargetAudienceMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_AUDIENCE_SIZE_FIELD_NUMBER: builtins.int
    CENSUS_AUDIENCE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def youtube_audience_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def census_audience_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        youtube_audience_size: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        census_audience_size: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "census_audience_size",
            b"census_audience_size",
            "youtube_audience_size",
            b"youtube_audience_size",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "census_audience_size",
            b"census_audience_size",
            "youtube_audience_size",
            b"youtube_audience_size",
        ],
    ) -> None: ...

global___OnTargetAudienceMetrics = OnTargetAudienceMetrics



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.manager_link_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClientLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_CUSTOMER_FIELD_NUMBER: builtins.int
    MANAGER_LINK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    client_customer: typing.Text = ...
    manager_link_id: builtins.int = ...
    status: google.ads.google_ads.v6.proto.enums.manager_link_status_pb2.ManagerLinkStatusEnum.ManagerLinkStatus.V = (
        ...
    )
    hidden: builtins.bool = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        client_customer: typing.Text = ...,
        manager_link_id: builtins.int = ...,
        status: google.ads.google_ads.v6.proto.enums.manager_link_status_pb2.ManagerLinkStatusEnum.ManagerLinkStatus.V = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_hidden",
            b"_hidden",
            "_manager_link_id",
            b"_manager_link_id",
            "client_customer",
            b"client_customer",
            "hidden",
            b"hidden",
            "manager_link_id",
            b"manager_link_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_client_customer",
            b"_client_customer",
            "_hidden",
            b"_hidden",
            "_manager_link_id",
            b"_manager_link_id",
            "client_customer",
            b"client_customer",
            "hidden",
            b"hidden",
            "manager_link_id",
            b"manager_link_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_client_customer", b"_client_customer"],
    ) -> typing_extensions.Literal["client_customer"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hidden", b"_hidden"]
    ) -> typing_extensions.Literal["hidden"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_manager_link_id", b"_manager_link_id"],
    ) -> typing_extensions.Literal["manager_link_id"]: ...

global___CustomerClientLink = CustomerClientLink



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignServingStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignServingStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignServingStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignServingStatusEnum.CampaignServingStatus.V(0)
        UNKNOWN = CampaignServingStatusEnum.CampaignServingStatus.V(1)
        SERVING = CampaignServingStatusEnum.CampaignServingStatus.V(2)
        NONE = CampaignServingStatusEnum.CampaignServingStatus.V(3)
        ENDED = CampaignServingStatusEnum.CampaignServingStatus.V(4)
        PENDING = CampaignServingStatusEnum.CampaignServingStatus.V(5)
        SUSPENDED = CampaignServingStatusEnum.CampaignServingStatus.V(6)
    class CampaignServingStatus(metaclass=_CampaignServingStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignServingStatusEnum.CampaignServingStatus.V(0)
    UNKNOWN = CampaignServingStatusEnum.CampaignServingStatus.V(1)
    SERVING = CampaignServingStatusEnum.CampaignServingStatus.V(2)
    NONE = CampaignServingStatusEnum.CampaignServingStatus.V(3)
    ENDED = CampaignServingStatusEnum.CampaignServingStatus.V(4)
    PENDING = CampaignServingStatusEnum.CampaignServingStatus.V(5)
    SUSPENDED = CampaignServingStatusEnum.CampaignServingStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___CampaignServingStatusEnum = CampaignServingStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.criteria_pb2
import google.ads.google_ads.v6.proto.common.custom_parameter_pb2
import google.ads.google_ads.v6.proto.enums.ad_group_criterion_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.ad_group_criterion_status_pb2
import google.ads.google_ads.v6.proto.enums.bidding_source_pb2
import google.ads.google_ads.v6.proto.enums.criterion_system_serving_status_pb2
import google.ads.google_ads.v6.proto.enums.criterion_type_pb2
import google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class QualityInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        QUALITY_SCORE_FIELD_NUMBER: builtins.int
        CREATIVE_QUALITY_SCORE_FIELD_NUMBER: builtins.int
        POST_CLICK_QUALITY_SCORE_FIELD_NUMBER: builtins.int
        SEARCH_PREDICTED_CTR_FIELD_NUMBER: builtins.int
        quality_score: builtins.int = ...
        creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
            ...
        )
        post_click_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
            ...
        )
        search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = (
            ...
        )
        def __init__(
            self,
            *,
            quality_score: builtins.int = ...,
            creative_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
            post_click_quality_score: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
            search_predicted_ctr: google.ads.google_ads.v6.proto.enums.quality_score_bucket_pb2.QualityScoreBucketEnum.QualityScoreBucket.V = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_quality_score", b"_quality_score", "quality_score", b"quality_score"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_quality_score",
                b"_quality_score",
                "creative_quality_score",
                b"creative_quality_score",
                "post_click_quality_score",
                b"post_click_quality_score",
                "quality_score",
                b"quality_score",
                "search_predicted_ctr",
                b"search_predicted_ctr",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_quality_score", b"_quality_score"],
        ) -> typing_extensions.Literal["quality_score"]: ...
    class PositionEstimates(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FIRST_PAGE_CPC_MICROS_FIELD_NUMBER: builtins.int
        FIRST_POSITION_CPC_MICROS_FIELD_NUMBER: builtins.int
        TOP_OF_PAGE_CPC_MICROS_FIELD_NUMBER: builtins.int
        ESTIMATED_ADD_CLICKS_AT_FIRST_POSITION_CPC_FIELD_NUMBER: builtins.int
        ESTIMATED_ADD_COST_AT_FIRST_POSITION_CPC_FIELD_NUMBER: builtins.int
        first_page_cpc_micros: builtins.int = ...
        first_position_cpc_micros: builtins.int = ...
        top_of_page_cpc_micros: builtins.int = ...
        estimated_add_clicks_at_first_position_cpc: builtins.int = ...
        estimated_add_cost_at_first_position_cpc: builtins.int = ...
        def __init__(
            self,
            *,
            first_page_cpc_micros: builtins.int = ...,
            first_position_cpc_micros: builtins.int = ...,
            top_of_page_cpc_micros: builtins.int = ...,
            estimated_add_clicks_at_first_position_cpc: builtins.int = ...,
            estimated_add_cost_at_first_position_cpc: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_estimated_add_clicks_at_first_position_cpc",
                b"_estimated_add_clicks_at_first_position_cpc",
                "_estimated_add_cost_at_first_position_cpc",
                b"_estimated_add_cost_at_first_position_cpc",
                "_first_page_cpc_micros",
                b"_first_page_cpc_micros",
                "_first_position_cpc_micros",
                b"_first_position_cpc_micros",
                "_top_of_page_cpc_micros",
                b"_top_of_page_cpc_micros",
                "estimated_add_clicks_at_first_position_cpc",
                b"estimated_add_clicks_at_first_position_cpc",
                "estimated_add_cost_at_first_position_cpc",
                b"estimated_add_cost_at_first_position_cpc",
                "first_page_cpc_micros",
                b"first_page_cpc_micros",
                "first_position_cpc_micros",
                b"first_position_cpc_micros",
                "top_of_page_cpc_micros",
                b"top_of_page_cpc_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_estimated_add_clicks_at_first_position_cpc",
                b"_estimated_add_clicks_at_first_position_cpc",
                "_estimated_add_cost_at_first_position_cpc",
                b"_estimated_add_cost_at_first_position_cpc",
                "_first_page_cpc_micros",
                b"_first_page_cpc_micros",
                "_first_position_cpc_micros",
                b"_first_position_cpc_micros",
                "_top_of_page_cpc_micros",
                b"_top_of_page_cpc_micros",
                "estimated_add_clicks_at_first_position_cpc",
                b"estimated_add_clicks_at_first_position_cpc",
                "estimated_add_cost_at_first_position_cpc",
                b"estimated_add_cost_at_first_position_cpc",
                "first_page_cpc_micros",
                b"first_page_cpc_micros",
                "first_position_cpc_micros",
                b"first_position_cpc_micros",
                "top_of_page_cpc_micros",
                b"top_of_page_cpc_micros",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_estimated_add_clicks_at_first_position_cpc",
                b"_estimated_add_clicks_at_first_position_cpc",
            ],
        ) -> typing_extensions.Literal[
            "estimated_add_clicks_at_first_position_cpc"
        ]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_estimated_add_cost_at_first_position_cpc",
                b"_estimated_add_cost_at_first_position_cpc",
            ],
        ) -> typing_extensions.Literal["estimated_add_cost_at_first_position_cpc"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_first_page_cpc_micros", b"_first_page_cpc_micros"
            ],
        ) -> typing_extensions.Literal["first_page_cpc_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_first_position_cpc_micros", b"_first_position_cpc_micros"
            ],
        ) -> typing_extensions.Literal["first_position_cpc_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_top_of_page_cpc_micros", b"_top_of_page_cpc_micros"
            ],
        ) -> typing_extensions.Literal["top_of_page_cpc_micros"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CRITERION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    QUALITY_INFO_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    SYSTEM_SERVING_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    DISAPPROVAL_REASONS_FIELD_NUMBER: builtins.int
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    CPM_BID_MICROS_FIELD_NUMBER: builtins.int
    CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    PERCENT_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPM_BID_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_PERCENT_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPC_BID_SOURCE_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPM_BID_SOURCE_FIELD_NUMBER: builtins.int
    EFFECTIVE_CPV_BID_SOURCE_FIELD_NUMBER: builtins.int
    EFFECTIVE_PERCENT_CPC_BID_SOURCE_FIELD_NUMBER: builtins.int
    POSITION_ESTIMATES_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    MOBILE_APP_CATEGORY_FIELD_NUMBER: builtins.int
    MOBILE_APPLICATION_FIELD_NUMBER: builtins.int
    LISTING_GROUP_FIELD_NUMBER: builtins.int
    AGE_RANGE_FIELD_NUMBER: builtins.int
    GENDER_FIELD_NUMBER: builtins.int
    INCOME_RANGE_FIELD_NUMBER: builtins.int
    PARENTAL_STATUS_FIELD_NUMBER: builtins.int
    USER_LIST_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_FIELD_NUMBER: builtins.int
    YOUTUBE_CHANNEL_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    USER_INTEREST_FIELD_NUMBER: builtins.int
    WEBPAGE_FIELD_NUMBER: builtins.int
    APP_PAYMENT_MODEL_FIELD_NUMBER: builtins.int
    CUSTOM_AFFINITY_FIELD_NUMBER: builtins.int
    CUSTOM_INTENT_FIELD_NUMBER: builtins.int
    CUSTOM_AUDIENCE_FIELD_NUMBER: builtins.int
    COMBINED_AUDIENCE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    criterion_id: builtins.int = ...
    status: google.ads.google_ads.v6.proto.enums.ad_group_criterion_status_pb2.AdGroupCriterionStatusEnum.AdGroupCriterionStatus.V = (
        ...
    )
    ad_group: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = (
        ...
    )
    negative: builtins.bool = ...
    system_serving_status: google.ads.google_ads.v6.proto.enums.criterion_system_serving_status_pb2.CriterionSystemServingStatusEnum.CriterionSystemServingStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v6.proto.enums.ad_group_criterion_approval_status_pb2.AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V = (
        ...
    )
    disapproval_reasons: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    bid_modifier: builtins.float = ...
    cpc_bid_micros: builtins.int = ...
    cpm_bid_micros: builtins.int = ...
    cpv_bid_micros: builtins.int = ...
    percent_cpc_bid_micros: builtins.int = ...
    effective_cpc_bid_micros: builtins.int = ...
    effective_cpm_bid_micros: builtins.int = ...
    effective_cpv_bid_micros: builtins.int = ...
    effective_percent_cpc_bid_micros: builtins.int = ...
    effective_cpc_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    effective_cpm_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    effective_cpv_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    effective_percent_cpc_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = (
        ...
    )
    final_urls: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    final_mobile_urls: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    final_url_suffix: typing.Text = ...
    tracking_url_template: typing.Text = ...
    @property
    def quality_info(self) -> global___AdGroupCriterion.QualityInfo: ...
    @property
    def position_estimates(self) -> global___AdGroupCriterion.PositionEstimates: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def keyword(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo: ...
    @property
    def placement(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.MobileApplicationInfo: ...
    @property
    def listing_group(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.ListingGroupInfo: ...
    @property
    def age_range(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.AgeRangeInfo: ...
    @property
    def gender(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.GenderInfo: ...
    @property
    def income_range(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.IncomeRangeInfo: ...
    @property
    def parental_status(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.ParentalStatusInfo: ...
    @property
    def user_list(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.UserListInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.YouTubeChannelInfo: ...
    @property
    def topic(self) -> google.ads.google_ads.v6.proto.common.criteria_pb2.TopicInfo: ...
    @property
    def user_interest(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.UserInterestInfo: ...
    @property
    def webpage(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.WebpageInfo: ...
    @property
    def app_payment_model(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.AppPaymentModelInfo: ...
    @property
    def custom_affinity(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.CustomAffinityInfo: ...
    @property
    def custom_intent(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.CustomIntentInfo: ...
    @property
    def custom_audience(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.CustomAudienceInfo: ...
    @property
    def combined_audience(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.CombinedAudienceInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        criterion_id: builtins.int = ...,
        status: google.ads.google_ads.v6.proto.enums.ad_group_criterion_status_pb2.AdGroupCriterionStatusEnum.AdGroupCriterionStatus.V = ...,
        quality_info: typing.Optional[global___AdGroupCriterion.QualityInfo] = ...,
        ad_group: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = ...,
        negative: builtins.bool = ...,
        system_serving_status: google.ads.google_ads.v6.proto.enums.criterion_system_serving_status_pb2.CriterionSystemServingStatusEnum.CriterionSystemServingStatus.V = ...,
        approval_status: google.ads.google_ads.v6.proto.enums.ad_group_criterion_approval_status_pb2.AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V = ...,
        disapproval_reasons: typing.Optional[typing.Iterable[typing.Text]] = ...,
        bid_modifier: builtins.float = ...,
        cpc_bid_micros: builtins.int = ...,
        cpm_bid_micros: builtins.int = ...,
        cpv_bid_micros: builtins.int = ...,
        percent_cpc_bid_micros: builtins.int = ...,
        effective_cpc_bid_micros: builtins.int = ...,
        effective_cpm_bid_micros: builtins.int = ...,
        effective_cpv_bid_micros: builtins.int = ...,
        effective_percent_cpc_bid_micros: builtins.int = ...,
        effective_cpc_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        effective_cpm_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        effective_cpv_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        effective_percent_cpc_bid_source: google.ads.google_ads.v6.proto.enums.bidding_source_pb2.BiddingSourceEnum.BiddingSource.V = ...,
        position_estimates: typing.Optional[
            global___AdGroupCriterion.PositionEstimates
        ] = ...,
        final_urls: typing.Optional[typing.Iterable[typing.Text]] = ...,
        final_mobile_urls: typing.Optional[typing.Iterable[typing.Text]] = ...,
        final_url_suffix: typing.Text = ...,
        tracking_url_template: typing.Text = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        keyword: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
        placement: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.PlacementInfo
        ] = ...,
        mobile_app_category: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.MobileAppCategoryInfo
        ] = ...,
        mobile_application: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.MobileApplicationInfo
        ] = ...,
        listing_group: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.ListingGroupInfo
        ] = ...,
        age_range: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.AgeRangeInfo
        ] = ...,
        gender: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.GenderInfo
        ] = ...,
        income_range: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.IncomeRangeInfo
        ] = ...,
        parental_status: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.ParentalStatusInfo
        ] = ...,
        user_list: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.UserListInfo
        ] = ...,
        youtube_video: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.YouTubeVideoInfo
        ] = ...,
        youtube_channel: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.YouTubeChannelInfo
        ] = ...,
        topic: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.TopicInfo
        ] = ...,
        user_interest: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.UserInterestInfo
        ] = ...,
        webpage: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.WebpageInfo
        ] = ...,
        app_payment_model: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.AppPaymentModelInfo
        ] = ...,
        custom_affinity: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.CustomAffinityInfo
        ] = ...,
        custom_intent: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.CustomIntentInfo
        ] = ...,
        custom_audience: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.CustomAudienceInfo
        ] = ...,
        combined_audience: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.CombinedAudienceInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_bid_modifier",
            b"_bid_modifier",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_criterion_id",
            b"_criterion_id",
            "_effective_cpc_bid_micros",
            b"_effective_cpc_bid_micros",
            "_effective_cpm_bid_micros",
            b"_effective_cpm_bid_micros",
            "_effective_cpv_bid_micros",
            b"_effective_cpv_bid_micros",
            "_effective_percent_cpc_bid_micros",
            b"_effective_percent_cpc_bid_micros",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_negative",
            b"_negative",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_group",
            b"ad_group",
            "age_range",
            b"age_range",
            "app_payment_model",
            b"app_payment_model",
            "bid_modifier",
            b"bid_modifier",
            "combined_audience",
            b"combined_audience",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "custom_audience",
            b"custom_audience",
            "custom_intent",
            b"custom_intent",
            "effective_cpc_bid_micros",
            b"effective_cpc_bid_micros",
            "effective_cpm_bid_micros",
            b"effective_cpm_bid_micros",
            "effective_cpv_bid_micros",
            b"effective_cpv_bid_micros",
            "effective_percent_cpc_bid_micros",
            b"effective_percent_cpc_bid_micros",
            "final_url_suffix",
            b"final_url_suffix",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "keyword",
            b"keyword",
            "listing_group",
            b"listing_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "negative",
            b"negative",
            "parental_status",
            b"parental_status",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "placement",
            b"placement",
            "position_estimates",
            b"position_estimates",
            "quality_info",
            b"quality_info",
            "topic",
            b"topic",
            "tracking_url_template",
            b"tracking_url_template",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_bid_modifier",
            b"_bid_modifier",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_criterion_id",
            b"_criterion_id",
            "_effective_cpc_bid_micros",
            b"_effective_cpc_bid_micros",
            "_effective_cpm_bid_micros",
            b"_effective_cpm_bid_micros",
            "_effective_cpv_bid_micros",
            b"_effective_cpv_bid_micros",
            "_effective_percent_cpc_bid_micros",
            b"_effective_percent_cpc_bid_micros",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_negative",
            b"_negative",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_group",
            b"ad_group",
            "age_range",
            b"age_range",
            "app_payment_model",
            b"app_payment_model",
            "approval_status",
            b"approval_status",
            "bid_modifier",
            b"bid_modifier",
            "combined_audience",
            b"combined_audience",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "custom_audience",
            b"custom_audience",
            "custom_intent",
            b"custom_intent",
            "disapproval_reasons",
            b"disapproval_reasons",
            "effective_cpc_bid_micros",
            b"effective_cpc_bid_micros",
            "effective_cpc_bid_source",
            b"effective_cpc_bid_source",
            "effective_cpm_bid_micros",
            b"effective_cpm_bid_micros",
            "effective_cpm_bid_source",
            b"effective_cpm_bid_source",
            "effective_cpv_bid_micros",
            b"effective_cpv_bid_micros",
            "effective_cpv_bid_source",
            b"effective_cpv_bid_source",
            "effective_percent_cpc_bid_micros",
            b"effective_percent_cpc_bid_micros",
            "effective_percent_cpc_bid_source",
            b"effective_percent_cpc_bid_source",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "keyword",
            b"keyword",
            "listing_group",
            b"listing_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "negative",
            b"negative",
            "parental_status",
            b"parental_status",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "placement",
            b"placement",
            "position_estimates",
            b"position_estimates",
            "quality_info",
            b"quality_info",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "system_serving_status",
            b"system_serving_status",
            "topic",
            b"topic",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_custom_parameters",
            b"url_custom_parameters",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_modifier", b"_bid_modifier"]
    ) -> typing_extensions.Literal["bid_modifier"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions.Literal["cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpm_bid_micros", b"_cpm_bid_micros"],
    ) -> typing_extensions.Literal["cpm_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions.Literal["cpv_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_criterion_id", b"_criterion_id"]
    ) -> typing_extensions.Literal["criterion_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_cpc_bid_micros", b"_effective_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["effective_cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_cpm_bid_micros", b"_effective_cpm_bid_micros"
        ],
    ) -> typing_extensions.Literal["effective_cpm_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_cpv_bid_micros", b"_effective_cpv_bid_micros"
        ],
    ) -> typing_extensions.Literal["effective_cpv_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_effective_percent_cpc_bid_micros", b"_effective_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["effective_percent_cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions.Literal["final_url_suffix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_negative", b"_negative"]
    ) -> typing_extensions.Literal["negative"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["percent_cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions.Literal["tracking_url_template"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["criterion", b"criterion"]
    ) -> typing_extensions.Literal[
        "keyword",
        "placement",
        "mobile_app_category",
        "mobile_application",
        "listing_group",
        "age_range",
        "gender",
        "income_range",
        "parental_status",
        "user_list",
        "youtube_video",
        "youtube_channel",
        "topic",
        "user_interest",
        "webpage",
        "app_payment_model",
        "custom_affinity",
        "custom_intent",
        "custom_audience",
        "combined_audience",
    ]: ...

global___AdGroupCriterion = AdGroupCriterion



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdServingOptimizationStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdServingOptimizationStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdServingOptimizationStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(0)
        UNKNOWN = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(1)
        OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(2)
        CONVERSION_OPTIMIZE = (
            AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(3)
        )
        ROTATE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(4)
        ROTATE_INDEFINITELY = (
            AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(5)
        )
        UNAVAILABLE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(6)
    class AdServingOptimizationStatus(metaclass=_AdServingOptimizationStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(0)
    UNKNOWN = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(1)
    OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(2)
    CONVERSION_OPTIMIZE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(
        3
    )
    ROTATE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(4)
    ROTATE_INDEFINITELY = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(
        5
    )
    UNAVAILABLE = AdServingOptimizationStatusEnum.AdServingOptimizationStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AdServingOptimizationStatusEnum = AdServingOptimizationStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AffiliateLocationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AffiliateLocationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AffiliateLocationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(0)
        )
        UNKNOWN = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(1)
        )
        BUSINESS_NAME = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(2)
        )
        ADDRESS_LINE_1 = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(3)
        )
        ADDRESS_LINE_2 = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(4)
        )
        CITY = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(5)
        )
        PROVINCE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(6)
        )
        POSTAL_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(7)
        )
        COUNTRY_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(8)
        )
        PHONE_NUMBER = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(9)
        )
        LANGUAGE_CODE = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                10
            )
        )
        CHAIN_ID = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                11
            )
        )
        CHAIN_NAME = (
            AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
                12
            )
        )
    class AffiliateLocationPlaceholderField(
        metaclass=_AffiliateLocationPlaceholderField
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(0)
    )
    UNKNOWN = AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(
        1
    )
    BUSINESS_NAME = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(2)
    )
    ADDRESS_LINE_1 = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(3)
    )
    ADDRESS_LINE_2 = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(4)
    )
    CITY = AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(5)
    PROVINCE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(6)
    )
    POSTAL_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(7)
    )
    COUNTRY_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(8)
    )
    PHONE_NUMBER = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(9)
    )
    LANGUAGE_CODE = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(10)
    )
    CHAIN_ID = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(11)
    )
    CHAIN_NAME = (
        AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField.V(12)
    )
    def __init__(
        self,
    ) -> None: ...

global___AffiliateLocationPlaceholderFieldEnum = AffiliateLocationPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class InteractionEventTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _InteractionEventType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            InteractionEventType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = InteractionEventTypeEnum.InteractionEventType.V(0)
        UNKNOWN = InteractionEventTypeEnum.InteractionEventType.V(1)
        CLICK = InteractionEventTypeEnum.InteractionEventType.V(2)
        ENGAGEMENT = InteractionEventTypeEnum.InteractionEventType.V(3)
        VIDEO_VIEW = InteractionEventTypeEnum.InteractionEventType.V(4)
        NONE = InteractionEventTypeEnum.InteractionEventType.V(5)
    class InteractionEventType(metaclass=_InteractionEventType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = InteractionEventTypeEnum.InteractionEventType.V(0)
    UNKNOWN = InteractionEventTypeEnum.InteractionEventType.V(1)
    CLICK = InteractionEventTypeEnum.InteractionEventType.V(2)
    ENGAGEMENT = InteractionEventTypeEnum.InteractionEventType.V(3)
    VIDEO_VIEW = InteractionEventTypeEnum.InteractionEventType.V(4)
    NONE = InteractionEventTypeEnum.InteractionEventType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___InteractionEventTypeEnum = InteractionEventTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2
import google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2
import google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FrequencyCapEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    CAP_FIELD_NUMBER: builtins.int
    @property
    def key(self) -> global___FrequencyCapKey: ...
    @property
    def cap(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        key: typing.Optional[global___FrequencyCapKey] = ...,
        cap: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["cap", b"cap", "key", b"key"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["cap", b"cap", "key", b"key"]
    ) -> None: ...

global___FrequencyCapEntry = FrequencyCapEntry

class FrequencyCapKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEVEL_FIELD_NUMBER: builtins.int
    EVENT_TYPE_FIELD_NUMBER: builtins.int
    TIME_UNIT_FIELD_NUMBER: builtins.int
    TIME_LENGTH_FIELD_NUMBER: builtins.int
    level: google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2.FrequencyCapLevelEnum.FrequencyCapLevel.V = (
        ...
    )
    event_type: google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2.FrequencyCapEventTypeEnum.FrequencyCapEventType.V = (
        ...
    )
    time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = (
        ...
    )
    @property
    def time_length(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    def __init__(
        self,
        *,
        level: google.ads.google_ads.v4.proto.enums.frequency_cap_level_pb2.FrequencyCapLevelEnum.FrequencyCapLevel.V = ...,
        event_type: google.ads.google_ads.v4.proto.enums.frequency_cap_event_type_pb2.FrequencyCapEventTypeEnum.FrequencyCapEventType.V = ...,
        time_unit: google.ads.google_ads.v4.proto.enums.frequency_cap_time_unit_pb2.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit.V = ...,
        time_length: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["time_length", b"time_length"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "event_type",
            b"event_type",
            "level",
            b"level",
            "time_length",
            b"time_length",
            "time_unit",
            b"time_unit",
        ],
    ) -> None: ...

global___FrequencyCapKey = FrequencyCapKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductBiddingCategoryStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ProductBiddingCategoryStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(0)
        UNKNOWN = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(1)
        ACTIVE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(2)
        OBSOLETE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(3)
    class ProductBiddingCategoryStatus(metaclass=_ProductBiddingCategoryStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(0)
    UNKNOWN = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(1)
    ACTIVE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(2)
    OBSOLETE = ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ProductBiddingCategoryStatusEnum = ProductBiddingCategoryStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    value: typing.Text = ...
    def __init__(
        self,
        *,
        key: typing.Text = ...,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_key", b"_key", "_value", b"_value", "key", b"key", "value", b"value"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_key", b"_key", "_value", b"_value", "key", b"key", "value", b"value"
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_key", b"_key"]
    ) -> typing_extensions.Literal["key"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___CustomParameter = CustomParameter



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdStrengthEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdStrength(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdStrength.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdStrengthEnum.AdStrength.V(0)
        UNKNOWN = AdStrengthEnum.AdStrength.V(1)
        PENDING = AdStrengthEnum.AdStrength.V(2)
        NO_ADS = AdStrengthEnum.AdStrength.V(3)
        POOR = AdStrengthEnum.AdStrength.V(4)
        AVERAGE = AdStrengthEnum.AdStrength.V(5)
        GOOD = AdStrengthEnum.AdStrength.V(6)
        EXCELLENT = AdStrengthEnum.AdStrength.V(7)
    class AdStrength(metaclass=_AdStrength):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdStrengthEnum.AdStrength.V(0)
    UNKNOWN = AdStrengthEnum.AdStrength.V(1)
    PENDING = AdStrengthEnum.AdStrength.V(2)
    NO_ADS = AdStrengthEnum.AdStrength.V(3)
    POOR = AdStrengthEnum.AdStrength.V(4)
    AVERAGE = AdStrengthEnum.AdStrength.V(5)
    GOOD = AdStrengthEnum.AdStrength.V(6)
    EXCELLENT = AdStrengthEnum.AdStrength.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AdStrengthEnum = AdStrengthEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PolicyReviewStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PolicyReviewStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PolicyReviewStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PolicyReviewStatusEnum.PolicyReviewStatus.V(0)
        UNKNOWN = PolicyReviewStatusEnum.PolicyReviewStatus.V(1)
        REVIEW_IN_PROGRESS = PolicyReviewStatusEnum.PolicyReviewStatus.V(2)
        REVIEWED = PolicyReviewStatusEnum.PolicyReviewStatus.V(3)
        UNDER_APPEAL = PolicyReviewStatusEnum.PolicyReviewStatus.V(4)
        ELIGIBLE_MAY_SERVE = PolicyReviewStatusEnum.PolicyReviewStatus.V(5)
    class PolicyReviewStatus(metaclass=_PolicyReviewStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PolicyReviewStatusEnum.PolicyReviewStatus.V(0)
    UNKNOWN = PolicyReviewStatusEnum.PolicyReviewStatus.V(1)
    REVIEW_IN_PROGRESS = PolicyReviewStatusEnum.PolicyReviewStatus.V(2)
    REVIEWED = PolicyReviewStatusEnum.PolicyReviewStatus.V(3)
    UNDER_APPEAL = PolicyReviewStatusEnum.PolicyReviewStatus.V(4)
    ELIGIBLE_MAY_SERVE = PolicyReviewStatusEnum.PolicyReviewStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___PolicyReviewStatusEnum = PolicyReviewStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdvertisingChannelSubTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdvertisingChannelSubType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdvertisingChannelSubType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(0)
        UNKNOWN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(1)
        SEARCH_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(2)
        DISPLAY_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            3
        )
        SEARCH_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(4)
        DISPLAY_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(5)
        SHOPPING_SMART_ADS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            6
        )
        DISPLAY_GMAIL_AD = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(7)
        DISPLAY_SMART_CAMPAIGN = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(8)
        )
        VIDEO_OUTSTREAM = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(9)
        VIDEO_ACTION = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(10)
        VIDEO_NON_SKIPPABLE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
            11
        )
        APP_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(12)
        APP_CAMPAIGN_FOR_ENGAGEMENT = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(13)
        )
        LOCAL_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(14)
        SHOPPING_COMPARISON_LISTING_ADS = (
            AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(15)
        )
        SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(16)
        VIDEO_SEQUENCE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(17)
    class AdvertisingChannelSubType(metaclass=_AdvertisingChannelSubType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(0)
    UNKNOWN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(1)
    SEARCH_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(2)
    DISPLAY_MOBILE_APP = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(3)
    SEARCH_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(4)
    DISPLAY_EXPRESS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(5)
    SHOPPING_SMART_ADS = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(6)
    DISPLAY_GMAIL_AD = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(7)
    DISPLAY_SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(
        8
    )
    VIDEO_OUTSTREAM = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(9)
    VIDEO_ACTION = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(10)
    VIDEO_NON_SKIPPABLE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(11)
    APP_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(12)
    APP_CAMPAIGN_FOR_ENGAGEMENT = (
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(13)
    )
    LOCAL_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(14)
    SHOPPING_COMPARISON_LISTING_ADS = (
        AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(15)
    )
    SMART_CAMPAIGN = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(16)
    VIDEO_SEQUENCE = AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V(17)
    def __init__(
        self,
    ) -> None: ...

global___AdvertisingChannelSubTypeEnum = AdvertisingChannelSubTypeEnum
